@@ -1,3 +1,4 @@
+/* SPDX-License-Identifier: GPL-2.0 WITH Linux-syscall-note */
 /*
  * include/linux/random.h
  *
@@ -34,9 +35,6 @@
 /* Clear the entropy pool and associated counters.  (Superuser only.) */
 #define RNDCLEARPOOL	_IO( 'R', 0x06 )
 
-/* Reseed CRNG.  (Superuser only.) */
-#define RNDRESEEDCRNG	_IO( 'R', 0x07 )
-
 struct rand_pool_info {
 	int	entropy_count;
 	int	buf_size;
@@ -47,11 +45,9 @@ struct rand_pool_info {
  * Flags for getrandom(2)
  *
  * GRND_NONBLOCK	Don't block and return EAGAIN instead
- * GRND_RANDOM		No effect
- * GRND_INSECURE	Return non-cryptographic random bytes
+ * GRND_RANDOM		Use the /dev/random pool instead of /dev/urandom
  */
 #define GRND_NONBLOCK	0x0001
 #define GRND_RANDOM	0x0002
-#define GRND_INSECURE	0x0004
 
 #endif /* _LINUX_RANDOM_H */
